# sre-tools

sre-tools is tools to help using stdlib `sre_parse`, including:

- helpers to create and clone `sre_parse.SubPattern`
- reduce complexity of a `sre_parse.SubPattern`
- split a `sre_parse.SubPattern`
